; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a logarithmic Y axis on a pressure plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "logarithmic_pressure_plot.pro" and run it like this::
;       IDL> .RUN logarithmic_pressure_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 18 August 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Logarithmic_Pressure_Plot
 
   ; Example data. Normally passed into the program as a positional parameter.
   data = cgScaleVector(cgDemoData(1), 30, 1200)
   height = cgScaleVector(Findgen(N_Elements(data)), 0, 6)
   thick = (!D.Name EQ 'PS') ? 4 : 2
   
   ; To label minor ticks on the axis use Martin Shultz program LogLevels.
   ; Set YTICKS to one less than the number of ticks returned by LogLevels.
   ticks = LogLevels([10,2000])
   nticks = N_Elements(ticks)

   ; Draw a plot with the Y axis labelled as a reversed logarithmic axis.
   cgPlot, height, data, /YLOG, YRANGE=[2000,10], YTICKS=nticks-1, $
       YTICKV=Reverse(ticks), /NoData, Position=[0.15, 0.125, 0.925, 0.9], $
       XTitle='Height', YTitle='Pressure', YMinor=5
    
   ; Add the data.
   cgOPlot, height, data, Color='red', Thick=thick
      
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Logarithmic_Pressure_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Logarithmic_Pressure_Plot', WBackground='White', $
     WTitle='Logarithmic Pressure Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'logarithmic_pressure_plot.ps'
  Logarithmic_Pressure_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'logarithmic_pressure_plot.ps', /PNG, Width=600

END